==> criawips_0.0.11.orig.tar.gz: criawips-0.0.11/src/rendering/cria-canvas-text.h <==
/* this file is part of criawips, a gnome presentation application
 *
 * AUTHORS
 *       Sven Herzberg        <herzi@gnome-de.org>
 *
 * Copyright (C) 2005 Sven Herzberg
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef CRIA_CANVAS_TEXT_H
#define CRIA_CANVAS_TEXT_H

#include <libgnomecanvas/gnome-canvas-text.h>

G_BEGIN_DECLS

typedef struct _CriaCanvasText CriaCanvasText;
typedef struct _GnomeCanvasTextClass CriaCanvasTextClass;

#define CRIA_TYPE_CANVAS_TEXT         (cria_canvas_text_get_type())
#define CRIA_CANVAS_TEXT(o)           (G_TYPE_CHECK_INSTANCE_CAST((o), CRIA_TYPE_CANVAS_TEXT, CriaCanvasText))
#define CRIA_CANVAS_TEXT_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), CRIA_TYPE_CANVAS_TEXT, CriaCanvasTextClass))
#define CRIA_IS_CANVAS_TEXT(o)        (G_TYPE_CHECK_INSTANCE_TYPE((o), CRIA_TYPE_CANVAS_TEXT))
#define CRIA_IS_CANVAS_TEXT_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE((k), CRIA_TYPE_CANVAS_TEXT))
#define CRIA_CANVAS_TEXT_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS((o), CRIA_TYPE_CANVAS_TEXT, CriaCanvasTextClass))

GType cria_canvas_text_get_type(void);

G_END_DECLS

#endif

==> criawips-0.0.12.tar.gz: criawips-0.0.12/src/rendering/cria-canvas-text.h <==
/* this file is part of criawips, a gnome presentation application
 *
 * AUTHORS
 *       Sven Herzberg        <herzi@gnome-de.org>
 *
 * Copyright (C) 2005 Sven Herzberg
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef CRIA_CANVAS_TEXT_H
#define CRIA_CANVAS_TEXT_H

#include <libgnomecanvas/gnome-canvas-text.h>

G_BEGIN_DECLS

typedef struct _CriaCanvasText CriaCanvasText;
typedef struct _CriaCanvasTextClass CriaCanvasTextClass;

#define CRIA_TYPE_CANVAS_TEXT         (cria_canvas_text_get_type())
#define CRIA_CANVAS_TEXT(o)           (G_TYPE_CHECK_INSTANCE_CAST((o), CRIA_TYPE_CANVAS_TEXT, CriaCanvasText))
#define CRIA_CANVAS_TEXT_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), CRIA_TYPE_CANVAS_TEXT, CriaCanvasTextClass))
#define CRIA_IS_CANVAS_TEXT(o)        (G_TYPE_CHECK_INSTANCE_TYPE((o), CRIA_TYPE_CANVAS_TEXT))
#define CRIA_IS_CANVAS_TEXT_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE((k), CRIA_TYPE_CANVAS_TEXT))
#define CRIA_CANVAS_TEXT_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS((o), CRIA_TYPE_CANVAS_TEXT, CriaCanvasTextClass))

GType cria_canvas_text_get_type(void);

G_END_DECLS

#endif
